@@ -44,13 +44,12 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
     name <- NULL
 
 ###  Section end: Dummy variables, only not to get NOTE's in pacakge checks
-    
     copy.data <- FALSE
     if(is.null(dir.data)){
         copy.data <- TRUE
     }     
     if(missing(files.needed)) files.needed <- NULL
-    extr.data <- NMextractDataFile(file.mod)
+    extr.data <- NMextractDataFile(file.mod,file.mod=file.mod,file.data="extract")
     
     if(is.null(extr.data$path.csv) && !is.null(extr.data$path)){
         extr.data$path.csv <- extr.data$path
@@ -74,9 +73,13 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
     dir.tmp <- fnExtension(fnAppend(file.mod,paste0("dir",sprintf(fmt="%04d",no.dir.new))),"")
     dir.create(dir.tmp)
     file.mod.tmp <- file.path(dir.tmp,fn.mod)
+
+    
     
 ### copy input data to temp dir. 
     if(copy.data){
+
+        
         file.copy(extr.data$path.csv,dir.tmp)
 ### modify .mod to use local copy of input data. Notice the newfile
 ### arg to NMwriteSection creating file.mod.tmp.
@@ -95,7 +98,7 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
             sec.data.new <- paste("$DATA",sec.data.new)
         }
     }
-    NMwriteSection(files=file.mod,section="DATA",newlines=sec.data.new,newfile=file.mod.tmp)
+    NMwriteSection(files=file.mod,section="DATA",newlines=sec.data.new,newfile=file.mod.tmp,quiet=TRUE)
 
 ### copy .phi if found
     ## file.copy(fnExtension(file.mod,"phi"),dir.tmp)
@@ -115,13 +118,14 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
         lines.bash <- c(
             "#!/bin/bash"
            ,sprintf("%s %s %s",path.nonmem,fn.mod,fnExtension(fn.mod,".lst"))
+           ,sprintf("cp \'%s\' \'%s\'",paste(meta.tables[,name],collapse=" "),dir.mod.abs)
 ### this works when file.mod is a relative path
             ## ,paste("find",".","-type f -name",paste0("*.",exts.cp)," -exec cp {} ",file.path(getwd(),dir.mod)," \\;")
             ## ,sprintf("cp %s %s",paste(meta.tables[,name],collapse=" "),file.path(getwd(),dir.mod))
 
 ### copy wanted files back to orig location of file.mod 
-           ,paste("find . -type f -name",paste0("\'*.",exts.cp,"\'")," -exec cp {} ",dir.mod.abs," \\;")
-           ,sprintf("cp %s %s",paste(meta.tables[,name],collapse=" "),dir.mod.abs)
+           ,paste0("find . -type f -name ",paste0("\'*.",exts.cp,"\'")," -exec cp {} \'",dir.mod.abs,"\' \\;")
+
            ,""
         )
         
